#! /usr/bin/env python3
# -*- coding: utf-8 -*-

import re
import random
import ikabot.config as config
from ikabot.web.sesion import get
from ikabot.helpers.pedirInfo import read
from ikabot.helpers.gui import enter

def sendToBot(s, msg, Token=False):
	if Token is False:
		msg = '{}\n{}'.format(config.infoUser, msg)
	with open(config.telegramFile, 'r') as filehandler:
		text = filehandler.read()
		(botToken, chatId) = text.splitlines()
		get('https://api.telegram.org/bot{}/sendMessage'.format(botToken), params={'chat_id': chatId, 'text': msg})

def telegramFileValido():
	with open(config.telegramFile, 'r') as filehandler:
		text = filehandler.read()
	rta = re.search(r'\d{6,}:[A-Za-z0-9_-]{34,}\n\d{8,9}', text)
	return rta is not None

def botValido(s):
	if telegramFileValido():
		return True
	else:
		print('Debe proporcionar las credenciales válidas para comunicarse por telegram.')
		print('Se requiere del token del bot a utilizar y de su chat_id')
		print('Para más informacion sobre como obtenerlos vea al readme de https://github.com/santipcn/ikabot')
		rta = read(msg='¿Porporcionará las credenciales ahora? [y/N]', values=['y','Y','n', 'N', ''])
		if rta.lower() != 'y':
			return False
		else:
			botToken = read(msg='Token del bot:')
			chat_id = read(msg='Chat_id:')
			with open(config.telegramFile, 'w') as filehandler:
				filehandler.write(botToken + '\n' + chat_id)
			rand = random.randint(1000, 9999)
			sendToBot(s, 'El token a ingresar es:{:d}'.format(rand), Token=True)
			rta = read(msg='Se envio un mensaje por telegram, ¿lo recibió? [Y/n]', values=['y','Y','n', 'N', ''])
			if rta.lower() == 'n':
				with open(config.telegramFile, 'w') as file:
					pass
				print('Revíse las credenciales y vuelva a proveerlas.')
				enter()
				return False
			else:
				recibido = read(msg='Ingrese el token recibido mediante telegram:', digit=True)
				if rand != recibido:
					with open(config.telegramFile, 'w') as file:
						pass
					print('El token es incorrecto')
					enter()
					return False
				else:
					print('El token es correcto.')
					enter()
					return True




ids = None
ciudades = None
infoUser = ''
cookieFile = '/tmp/.cookies.txt'
telegramFile = '/tmp/.telegram.txt'
urlCiudad = 'view=city&cityId='
urlIsla = 'view=island&islandId='
prompt = ' >>  '
tipoDeBien = ['Madera', 'Vino', 'Marmol', 'Cristal', 'Azufre']



#! /usr/bin/env python3
# -*- coding: utf-8 -*-

import traceback
from ikabot.helpers.botComm import *
from ikabot.helpers.gui import *
from ikabot.helpers.pedirInfo import *
from ikabot.helpers.planearViajes import planearViajes
from ikabot.helpers.signals import setInfoSignal
from ikabot.helpers.getJson import getCiudad
from ikabot.helpers.process import forkear
from ikabot.helpers.varios import addPuntos
from ikabot.helpers.recursos import *

def menuRutaComercial(s):
	rutas = []
	while True:

		banner()
		print('Ciudad de origen:')
		try:
			ciudadO = elegirCiudad(s)
		except KeyboardInterrupt:
			if rutas:
				print('¿Enviar viajes? [Y/n]')
				rta = read(values=['y', 'Y', 'n', 'N', ''])
				if rta.lower() != 'n':
					break
			return
		html = ciudadO['html']
		max = getRecursosDisponibles(html)
		total = list(map(int, max))

		banner()
		print('Ciudad de destino')
		ciudadD = elegirCiudad(s, ajenas=True)
		idIsla = ciudadD['islandId']

		if ciudadO['id'] == ciudadD['id']:
			continue

		if ciudadD['propia']:
			html = ciudadD['html']
			mad, vin, mar, cri, azu = getRecursosDisponibles(html, num=True)
			capacidad = getCapacidadDeAlmacenamiento(html)
			capacidad = int(capacidad)
			mad = capacidad - mad
			vin = capacidad - vin
			mar = capacidad - mar
			cri = capacidad - cri
			azu = capacidad - azu

		resto = total
		for ruta in rutas:
			(origen, destino, _, md, vn, mr, cr, az) = ruta
			if origen['id'] == ciudadO['id']:
				resto = (resto[0] - md, resto[1] - vn, resto[2] - mr, resto[3] - cr, resto[4] - az)
			if ciudadD['propia'] and destino['id'] == ciudadD['id']:
				mad = mad - md
				vin = vin - vn
				mar = mar - mr
				cri = cri - cr
				azu = azu - az

		banner()
		if ciudadD['propia']:
			msg = ''
			if resto[0] > mad:
				msg += '{} más de madera\n'.format(addPuntos(mad))
			if resto[1] > vin:
				msg += '{} más de vino\n'.format(addPuntos(vin))
			if resto[2] > mar:
				msg += '{} más de marmol\n'.format(addPuntos(mar))
			if resto[3] > cri:
				msg += '{} más de cristal\n'.format(addPuntos(cri))
			if resto[4] > azu:
				msg += '{} más de azufre\n'.format(addPuntos(azu))
			if msg:
				print('Solo puede almacenar:\n' + msg)
		print('Disponible:')
		print('Madera {} Vino {} Marmol {} Cristal {} Azufre {}'.format(addPuntos(resto[0]), addPuntos(resto[1]), addPuntos(resto[2]), addPuntos(resto[3]), addPuntos(resto[4])))
		print('Enviar:')
		try:
			md = pedirValor(' Madera:', resto[0])
			vn = pedirValor('   Vino:', resto[1])
			mr = pedirValor(' Marmol:', resto[2])
			cr = pedirValor('Cristal:', resto[3])
			az = pedirValor(' Azufre:', resto[4])
		except KeyboardInterrupt:
			continue
		if md + vn + mr + cr + az == 0:
			continue

		banner()
		print('Por enviar de {} a {}'.format(ciudadO['cityName'], ciudadD['cityName']))
		enviado = ''
		if md:
			enviado += 'Madera:{} '.format(addPuntos(md))
		if vn:
			enviado += 'Vino:{} '.format(addPuntos(vn))
		if mr:
			enviado += 'Marmol:{} '.format(addPuntos(mr))
		if cr:
			enviado += 'Cristal:{} '.format(addPuntos(cr))
		if az:
			enviado += 'Azufre:{}'.format(addPuntos(az))
		print(enviado)
		print('¿Proceder? [Y/n]')
		rta = read(values=['y', 'Y', 'n', 'N', ''])
		if rta.lower() != 'n':
			ruta = (ciudadO, ciudadD, idIsla, md, vn, mr, cr, az)
			rutas.append(ruta)
			print('¿Realizar otro envio? [y/N]')
			rta = read(values=['y', 'Y', 'n', 'N', ''])
			if rta.lower() != 'y':
				break

	forkear(s)
	if s.padre is True:
		return

	info = '\nRuta comercial\n'
	for ruta in rutas:
		(ciudadO, ciudadD, idIsla, md, vn, mr, cr, az) = ruta
		info = info + '{} -> {}\nMadera: {} Vino: {} Marmol: {} Cristal: {} Azufre: {}\n'.format(ciudadO['cityName'], ciudadD['cityName'], addPuntos(md), addPuntos(vn), addPuntos(mr), addPuntos(cr), addPuntos(az))

	setInfoSignal(s, info)
	try:
		planearViajes(s, rutas)
	except:
		if telegramFileValido():
			msg = 'Error en:\n{}\nCausa:\n{}'.format(info, traceback.format_exc())
			sendToBot(s, msg)
	finally:
		s.logout()



#! /usr/bin/env python3
# -*- coding: utf-8 -*-

from decimal import *

getcontext().prec = 30

def addPuntos(num):
	return '{0:,}'.format(int(num)).replace(',','.')

def diasHorasMinutos(segundosTotales):
	dias = int(segundosTotales / Decimal(86400))
	segundosTotales -= dias * Decimal(86400)
	horas = int(segundosTotales / Decimal(3600))
	segundosTotales -= horas * Decimal(3600)
	minutos = int(segundosTotales / Decimal(60))
	texto = ''
	if dias > 0:
		texto = str(dias) + 'D '
	if horas > 0:
		texto = texto + str(horas) + 'H '
	if minutos > 0 and dias == 0:
		texto = texto + str(minutos) + 'M '
	return texto
